@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AdvancedMailServer.py 10066 2017-06-24 02:58:55Z David $
+# $Id: AdvancedMailServer.py 10079 2017-07-03 13:52:00Z David $
 #
 # Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10066 $
+# $Revision: 10079 $
 
 from datetime import datetime, timedelta
 
@@ -151,13 +151,9 @@ class AdvancedMailServer(object):
         """
         from django.db.models import Count
         
-        # TODO: ContactMailingStatus.REJECTED will cause exception 
-        # type object 'ContactMailingStatus' has no attribute 'REJECTED'
-        # see https://sentry.nuwainfo.com/nuwa/nuwa_newsletter/group/866/
-        # try to find out whether is version difference or migration error.
-        
-        _status = [ContactMailingStatus.ERROR, ContactMailingStatus.INVALID,]
-                #   ContactMailingStatus.REJECTED]
+        _status = [ContactMailingStatus.ERROR, ContactMailingStatus.INVALID,
+                   ContactMailingStatus.REJECTED]
+                
         for newsletter in Newsletter.objects.filter(status=Newsletter.SENDING):
             try:
                 self.logger.info(
