@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 9603 2016-03-30 06:56:51Z Judy $
+# $Id: Mailer.py 10241 2017-09-01 14:08:47Z David $
 #
 # Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $ (Last)
+# $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 9603 $
+# $Revision: 10241 $
 
 import os
 import random
@@ -92,11 +92,12 @@ class CloudSMTP(object):
                 mail.send(fail_silently=False)
 
                 extra = mail.extra_headers
+                messageId = extra.get('messageId', '')
                 requestId = extra.get('request_id', '')
                 message = extra.get('message', '')
 
                 cloudSrv.recordSendInformation(
-                    self.newsletter, contact, requestId, message)
+                    self.newsletter, contact, messageId, message)
 
             if not self.test:
                 self.newsletter.status = Newsletter.SENT
